function ReaderOutput = Step1_EV(ReaderInput)
% input type 1 - EV file
% input type 2 - raw func file (nii.gz) to get NumTrs


try
    A = ReaderInput.Files;
end

switch exist('A')
    case 0
        msgbox({'This function extracts necessary info from the functional EV files.';'input type 1 - EV file';'input type 2 - raw func file (nii.gz) to get NumTrs'});
        uiwait;
        ReaderOutput.TrialName = [];
        ReaderOutput.Data = 1;
    otherwise
        strsep = EnableHelperFunction([],{'strsep.m'});
        BaseDirectory = cd;
        home;

        set(ReaderInput.ProgramStatusIndicator,'string','Running EV extractor ... ','foregroundcolor','g');drawnow;

        try

            ReaderOutput.ReaderName = 'EV';

            fid = fopen(ReaderInput.Files{1});

            Line1 = fgetl(fid);
            temp = strsep(Line1,':');
            ReaderOutput.TrialDescription = temp{1};

            a = strfind(Line1,'on');
            b = strfind(Line1,'at');

            ReaderOutput.Data.Date = Line1(a(end)+3:b(end)-2);
            ReaderOutput.Data.StartTime = Line1(b(end)+3:end);
            StartTime = ReaderOutput.Data.StartTime;

            temp = strsep(ReaderInput.Files{1},ReaderInput.PathSep);
            temp2 = strsep(temp{end},'.');
            ReaderOutput.TrialName = temp2{1};

            Line = fgetl(fid);

            TrCount = 0;
            VasCount = 1;
            TStartCount = 1;
            TEndCount = 1;
            DoingCount = 1;

            while isempty(strfind(Line,'Trial finished')) == 1
                if isempty(strfind(Line,'fMRI volume')) == 0
                    b = strfind(Line,'at');
                    time = Line(b(end)+3:end);
                    ReaderOutput.Data.TR(TrCount+1,1).Index = TrCount;
                    ReaderOutput.Data.TR(TrCount+1,1).Time = TimeDifference(StartTime,time);
                    TrCount = TrCount+1;
                end
                if isempty(strfind(Line,'VAS changed')) == 0
                    a = strfind(Line,'to');
                    b = strfind(Line,'at');
                    time = Line(b(end)+3:end);
                    ReaderOutput.Data.VAS(VasCount,1).Time = TimeDifference(StartTime,time);
                    ReaderOutput.Data.VAS(VasCount,1).Value = str2num(Line(a+3:b-2));
                    VasCount = VasCount+1;
                end
                if isempty(strfind(Line,'Therapist started')) == 0
                    a = strfind(Line,'ed');
                    b = strfind(Line,'at');
                    time = Line(b(end)+3:end);
                    ReaderOutput.Data.TherapistStarted(TStartCount,1).Time = TimeDifference(StartTime,time);
                    ReaderOutput.Data.TherapistStarted(TStartCount,1).Action = Line(a+3:b-2);
                    TStartCount = TStartCount + 1;
                end
                if isempty(strfind(Line,'Therapist finished')) == 0
                    a = strfind(Line,'ed');
                    b = strfind(Line,'at');
                    time = Line(b(end)+3:end);
                    ReaderOutput.Data.TherapistFinished(TEndCount,1).Time = TimeDifference(StartTime,time);
                    ReaderOutput.Data.TherapistFinished(TEndCount,1).Action = Line(a+3:b-2);
                    TEndCount = TEndCount + 1;
                end
                if isempty(strfind(Line,'Doing')) == 0
                    a = strfind(Line,'ng');
                    b = strfind(Line,'at');
                    time = Line(b(end)+3:end);
                    ReaderOutput.Data.Contraction(DoingCount,1).StartTime = TimeDifference(StartTime,time);
                    ReaderOutput.Data.Contraction(DoingCount,1).Type = Line(a+3:b-2);
                    DoingCount = DoingCount + 1;
                end


                Line = fgetl(fid);
            end

            b = strfind(Line,'at');
            time = Line(b(end)+3:end);
            ReaderOutput.Data.EndTime = TimeDifference(StartTime,time);


            if length(ReaderInput.Files) > 1
            cd('HelperFunctions/nifti/');
            system(['gunzip ' ReaderInput.Files{2}]); 
            func_nii = load_nii(ReaderInput.Files{2}(1:end-3));
            system(['gzip ' ReaderInput.Files{2}(1:end-3)]);
            ActualNumTrs = size(func_nii.img,4);
            temp = strsep(ReaderInput.Files{2},'.');
            ReaderOutput.Data.FuncImageFile = temp{1};
            end

            EstimatedNumTrs = length(ReaderOutput.Data.TR);
            NumToTrim = EstimatedNumTrs-ActualNumTrs;

            if NumToTrim > 0
                ReaderOutput.Data.TR(1:NumToTrim) = [];
            end

            Add = EstimatedNumTrs;

            if NumToTrim < 0
               for i = 1:abs(NumToTrim)
                  ReaderOutput.Data.TR(Add+1).Index = ReaderOutput.Data.TR(Add).Index + 1;
                  ReaderOutput.Data.TR(Add+1).Time = ReaderOutput.Data.TR(Add).Time + 2;
                  Add = Add+1;
               end
            end

            cd(BaseDirectory);



        catch err

            set(ReaderInput.ProgramStatusIndicator,'string','Reader Step1_EV exited with an error. See matlab window for details.','foregroundcolor','r');drawnow;
            pause(2);
            set(ReaderInput.ProgramStatusIndicator,'string','Ready.','foregroundcolor','k');drawnow;
            cd(BaseDirectory);

            ReaderOutput.Data = [];

            rethrow(err);


        end
end

function deltaT = TimeDifference(str1,str2)

K = strfind(str1,':');
H1 = str2num(str1(1:K(1)-1));
M1 = str2num(str1(K(1)+1:K(2)-1));
S1 = str2num(str1(K(2)+1:end));

K = strfind(str2,':');
H2 = str2num(str2(1:K(1)-1));
M2 = str2num(str2(K(1)+1:K(2)-1));
S2 = str2num(str2(K(2)+1:end));

deltaH = H2-H1;
deltaM = M2-M1;
deltaS = S2-S1;

deltaT = 60^2*deltaH + 60*deltaM + deltaS;