function ReaderOutput = PreStatsReader(ReaderInput)
% input1 = filtered func data (.nii.gz)

% Enable Helper Functions
strsep = EnableHelperFunction([],'strsep.m');

FslStr = 'FSLDIR=/usr/local/fsl ; PATH=${FSLDIR}/bin:${PATH} ; . ${FSLDIR}/etc/fslconf/fsl.sh ; export FSLDIR PATH';

try

    ReaderOutput.ReaderName = 'PreStats';
    ReaderOutput.TrialName = '';
    ReaderOutput.TrialDescription = '';
    ReaderOutput.Data = '';

    BaseDirectory = cd;

    % create mprage brain on func volume
    set(ReaderInput.ProgramStatusIndicator,'string','Mapping mprage_brain to func coordinates...','foregroundcolor','g');drawnow;
    PreStatsDir = fileparts(ReaderInput.Files{1});
    system([FslStr ' ; applyxfm4d ' PreStatsDir '/reg/highres.nii.gz ' PreStatsDir '/filtered_func_data.nii.gz ' PreStatsDir '/mprage_brain_on_func.nii.gz ' PreStatsDir '/reg/highres2example_func.mat -singlematrix']);

    % write the path to prestats folder
    ReaderOutput.Data.Path = PreStatsDir;

    % read nii filtered func data
    cd('HelperFunctions/nifti');
    system(['gunzip ' ReaderInput.Files{1}]); 
    % set(ReaderInput.ProgramStatusIndicator,'string','Reslicing func data');drawnow;
    % reslice_nii(ReaderInput.Files{1}(1:end-3),ReaderInput.Files{1}(1:end-3));
    nii = load_nii(ReaderInput.Files{1}(1:end-3));
    system(['gzip ' ReaderInput.Files{1}(1:end-3)]);

    ReaderOutput.Data.filtered_func_data = nii;

    % get estimated head motions
    A = load([PreStatsDir '/mc/prefiltered_func_data_mcf.par']);

    ReaderOutput.Data.prefiltered_func_data_mcf.Rotations.Value = A(:,1:3);
    ReaderOutput.Data.prefiltered_func_data_mcf.Rotations.ColumnLabels = 'x,y,z';
    ReaderOutput.Data.prefiltered_func_data_mcf.Rotations.Units = 'radians';

    ReaderOutput.Data.prefiltered_func_data_mcf.Translations.Value = A(:,4:6);
    ReaderOutput.Data.prefiltered_func_data_mcf.Translations.ColumnLabels = 'x,y,z';
    ReaderOutput.Data.prefiltered_func_data_mcf.Translations.Units = 'mm';

    % read mprage_brain in func space
    mpragebrainonfuncfile = [PreStatsDir '/mprage_brain_on_func.nii.gz'];

    system(['gunzip ' mpragebrainonfuncfile]); 
    % set(ReaderInput.ProgramStatusIndicator,'string','Reslicing mprage _brainon func...');drawnow;
    % reslice_nii(mpragebrainonfuncfile(1:end-3),mpragebrainonfuncfile(1:end-3));
    nii = load_nii(mpragebrainonfuncfile(1:end-3));
    system(['gzip ' mpragebrainonfuncfile(1:end-3)]);

    ReaderOutput.Data.mprage_brain_on_func = nii;

    cd(BaseDirectory);
    
catch err
    
    set(ReaderInput.ProgramStatusIndicator,'string','Reader Step2_Prestats exited with an error. See matlab window for details.','foregroundcolor','r');drawnow;
    pause(2);
    set(ReaderInput.ProgramStatusIndicator,'string','Ready.','foregroundcolor','k');drawnow;
    cd(BaseDirectory);
    
    ReaderOutput.Data = [];
    
    rethrow(err);
    
end