function ReaderOutput = Step5_AddAtlas(ReaderInput)
% input 1 - filtered_func_data (.nii.gz)
% input 2 - standard2example_func.mat

BaseStatus = get(ReaderInput.ProgramStatusIndicator,'string');

% atlas to use
CortAtlas = 'HarvardOxford-cort-prob-2mm';
SubCortAtlas = 'HarvardOxford-sub-prob-2mm';

% string needed to execute FSL commands
FslStr = 'FSLDIR=/usr/local/fsl ; PATH=${FSLDIR}/bin:${PATH} ; . ${FSLDIR}/etc/fslconf/fsl.sh ; export FSLDIR PATH';

ReaderOutput.ReaderName = 'Atlas';
ReaderOutput.TrialName = '';
ReaderOutput.TrialDescription = '';

BaseDirectory = cd;

% create atlas on func volume

AtlasDir = '/Users/amplmember/Documents/DatabaserProject/HelperFunctions/fMRI/Atlases';

[PreStatsDir,TrialName,TrialExt] = fileparts(ReaderInput.Files{1});

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : applyxfm4d to ' CortAtlas]); drawnow;  
system([FslStr ' ; applyxfm4d ' AtlasDir '/' CortAtlas '.nii.gz ' ReaderInput.Files{1} ' ' PreStatsDir '/' CortAtlas '_on_func.nii.gz ' ReaderInput.Files{2} ' -singlematrix']);

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : applyxfm4d to ' SubCortAtlas]); drawnow
system([FslStr ' ; applyxfm4d ' AtlasDir '/' SubCortAtlas '.nii.gz ' ReaderInput.Files{1} ' ' PreStatsDir '/' SubCortAtlas '_on_func.nii.gz ' ReaderInput.Files{2} ' -singlematrix']);

CortAtlasOnFunc = [PreStatsDir '/' CortAtlas '_on_func.nii.gz'];
SubCortAtlasOnFunc = [PreStatsDir '/' SubCortAtlas '_on_func.nii.gz'];

cd('HelperFunctions/nifti/');
set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : loading nii for ' CortAtlas]); drawnow;
system(['gunzip ' CortAtlasOnFunc]);
nii_cort = load_nii([CortAtlasOnFunc(1:end-3)]);
system(['gzip ' CortAtlasOnFunc(1:end-3)]);

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : loading nii for ' SubCortAtlas]); drawnow;
system(['gunzip ' SubCortAtlasOnFunc]);
nii_subcort = load_nii([SubCortAtlasOnFunc(1:end-3)]);
system(['gzip ' SubCortAtlasOnFunc(1:end-3)]);

cd(BaseDirectory);

load HelperFunctions/fMRI/Atlases/HarvardOxfordCombinedRegionLabels.mat

ReaderOutput.Data.RegionLabel = RegionLabel;
ReaderOutput.Data.RegionProbMap = nii_cort;

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : preallocating combined img ']); drawnow;
img = zeros(size(nii_cort.img,1),size(nii_cort.img,2),size(nii_cort.img,3),length(RegionLabel));

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : filling combined img with ' CortAtlas]); drawnow;
c = 1;
for i = 1:size(nii_cort.img,4)
    img(:,:,:,c) = nii_cort.img(:,:,:,i);
    c = c+1;
end

set(ReaderInput.ProgramStatusIndicator,'string',[BaseStatus ' : filling combined img with ' SubCortAtlas]); drawnow;

for i = 1:size(nii_subcort.img,4)
    img(:,:,:,c) = nii_subcort.img(:,:,:,i);
    c = c+1;
end

ReaderOutput.Data.RegionProbMap.img = img;
ReaderOutput.Data.RegionProbMap.hdr.dime.dim(5) = length(RegionLabel);