function ReaderOutput = DesmedtReader(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction([],{'strsep.m'});

temp = strsep(ReaderInput.Files{1},ReaderInput.PathSep);
temp2 = strsep(temp{end},'_');

ReaderOutput.TrialName = temp2{1};
ReaderOutput.TrialDescription = 'Default';
ReaderOutput.ReaderName = 'DecompResults';

set(ReaderInput.ProgramStatusIndicator,'string','Reading firings...'); drawnow;
Firings = csvread(ReaderInput.Files{1});
set(ReaderInput.ProgramStatusIndicator,'string','Finished firings, reading Templates...'); drawnow;
Templates = csvread(ReaderInput.Files{2});

NumMotorUnits = size(Firings,2)-1;

for i = 1:NumMotorUnits
    try
        ReaderOutput.Data.MotorUnit(i).SpikeTrain = Firings(Firings(:,i+1)==1,1);
        for j = 1:4
            ReaderOutput.Data.MotorUnit(i).Template.Channel(j).Time = Templates(:,(i-1)*8+(j-1)*2+1);
            ReaderOutput.Data.MotorUnit(i).Template.Channel(j).Signal = Templates(:,(i-1)*8+(j-1)*2+2);
        end
    catch
        
    end
end

