function ReaderOutput = SignalReader(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

JR3CalibrationUsc = EnableHelperFunction([],{'JR3CalibrationUsc.m'});

ReaderOutput.ReaderName = 'Raw';
ReaderOutput.TrialDescription = '';
ReaderOutput.TrialName = '';

set(ReaderInput.ProgramStatusIndicator,'string','Reading raw data (may take some time)...'); drawnow;
A = csvread(ReaderInput.Files{1});
set(ReaderInput.ProgramStatusIndicator,'string','Finished reading raw data.'); drawnow;


SamplingFreq = 20000;
EmgInd = [2 4 6 8];
Jr3Ind = [9 10 11 12 13 14];

ReaderOutput.Data.Time.Units = 'Seconds';
ReaderOutput.Data.Time.Value = 1/SamplingFreq*[0:size(A,1)-1];

ReaderOutput.Data.SamplingFrequency.Units = 'Hz';
ReaderOutput.Data.SamplingFrequency.Value = SamplingFreq;

for i = 1:4
    ReaderOutput.Data.EmgChannel(i).Units = 'Volts';
    ReaderOutput.Data.EmgChannel(i).Value = A(:,EmgInd(i));
end

Jr3V = A(:,Jr3Ind);
Jr3E = JR3CalibrationUsc(Jr3V);

for i = 1:3
   ReaderOutput.Data.WrenchChannel(i).Units = 'Newtons';
   ReaderOutput.Data.WrenchChannel(i).Value = Jr3E(:,i);
end

for i = 4:6
   ReaderOutput.Data.WrenchChannel(i).Units = 'NewtonMeters';
   ReaderOutput.Data.WrenchChannel(i).Value = Jr3E(:,i);
end



