function ReaderOutput = ReadViconDataOnly(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription
strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');
ProgramStatusIndicator = ReaderInput.ProgramStatusIndicator;

ViconDataFile = ReaderInput.Files{1};
parts=strsep(ViconDataFile);

viconMarkers=csvread(viconDataFile,[9,0,10,0])
viconData=csvread(viconDataFile,11,0);

save('V',viconData)
ReaderOutput=[];