function ReaderOutput = ReadViconDataOnly(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription
strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');
ProgramStatusIndicator = ReaderInput.ProgramStatusIndicator;

ViconDataFile = ReaderInput.Files{1};

fid = fopen(ViconDataFile);

Title = strsep(fgetl(fid),',');
Date = strsep(fgetl(fid),',');

fname = strsep(ViconDataFile,'.');

Time = strsep(fgetl(fid),',');

Type = strsep(fgetl(fid),',');

Description = strsep(fgetl(fid),',');

Notes = strsep(fgetl(fid),',');

fgetl(fid);   % skipped line
fgetl(fid);   % TRAJECTORIES

SampFreq = strsep(fgetl(fid),',');

Objects = strsep(fgetl(fid),',');

c = 1;
for i = 1:length(Objects)
    if isempty(Objects{i}) == 0
        MarkersRaw{c} = Objects{i};
        c = c+1;
    end
end    
Labels = strsep(fgetl(fid),',');

markers=RearrangeMarkers(MarkersRaw);

fclose(fid);

end

function markers= RearrangeMarkers(markers)
markerOrder=[ find(strcmp(markers,'G1')==1) find(strcmp(markers,'G2')==1) ...
    find(strcmp(markers,'G3')==1) find(strcmp(markers,'P1')==1) ...
    find(strcmp(markers,'P2')==1) find(strcmp(markers,'P3')==1) ...
    find(strcmp(markers,'M1')==1) find(strcmp(markers,'M2')==1) ...
    find(strcmp(markers,'M3')==1) find(strcmp(markers,'D1')==1) ...
    find(strcmp(markers,'D2')==1) find(strcmp(markers,'D3')==1) ...
    find(strcmp(markers,'fingerTip')==1)
find(strcmp(markers,'EIP')==1) find(strcmp(markers,'EDC')==1)...
find(strcmp(markers,'LUM')==1) find(strcmp(markers,'FDI')==1)...
find(strcmp(markers,'FPI')==1)];

dataFco=data(:,muscOrder);
end