function ReaderOutput = EwaerReader(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction([],'strsep.m');

set(ReaderInput.ProgramStatusIndicator,'string','Loading daq file, please wait...');
pause(0.1);
[data,time] = daqread(ReaderInput.Files{1});
set(ReaderInput.ProgramStatusIndicator,'string','Finished reading daq file');
pause(0.1);

load(ReaderInput.Files{2});
% has EmgEwaDir and TimeStamps

tmp = strsep(ReaderInput.Files{1},'/');

ReaderOutput.TrialName = tmp{end}(1:end-4);
ReaderOutput.TrialDescription = 'a series of EWA trials, some are flexion, some are abduction'; % put in metadata
ReaderOutput.ReaderName = 'AllData';

ChannelName = {'VFx';'VFy';'VFz';'VMx';'VMy';'VMz';'FdiEmg'}; % put in metadata

ReaderOutput.Data.Time = time;
ReaderOutput.Data.TimeUnits = 'seconds';
ReaderOutput.Data.SampFreq = 2000;
ReaderOutput.Data.SampFreqUnits = 'Hz';


TrialCount = 1;

while isnan(TimeStamps(TrialCount,2)) == 0
    
    ReaderOutput.Data.Meta.ActiveInterval(TrialCount,:) = TimeStamps(TrialCount,:);
    ReaderOutput.Data.Meta.RealTimeEmg(TrialCount,1) = EmgEwaDir(TrialCount,1);
    ReaderOutput.Data.Meta.RealTimeEwa(TrialCount,1) = EmgEwaDir(TrialCount,2);
    ReaderOutput.Data.Meta.RealTimeDir(TrialCount,1) = EmgEwaDir(TrialCount,3);
    
    TrialCount = TrialCount + 1;
end


for i = 1:7
    ReaderOutput.Data.Raw.Channel(i).Name =  ChannelName{i};
    ReaderOutput.Data.Raw.Channel(i).Value = data(:,i);
end


