function ReaderOutput = FFSReader(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that

strsep = EnableHelperFunction([],'strsep.m');

dm = load(ReaderInput.Files{1});

A = reshape(dm',size(dm,1)*size(dm,2),1);

BufferLength = 100;
NumDataColumns = size(dm,2)/BufferLength;

B = reshape(A,NumDataColumns,length(A)/NumDataColumns)';

ReaderOutput.ReaderName = 'FFS';

temp = strsep(ReaderInput.Files{1},ReaderInput.PathSep);

ReaderOutput.TrialName = temp{end}(1:end-4);
ReaderOutput.TrialDescription = 'Not available';
dlgprompt={'Trial Description:','Ramp up time (s):','Hold time (s):','Ramp down time (s)',...
    'Number of tendons:','Sampling rate (Hz):','Baseline tension (N):','Tension range (N)','Joint angle vector in degrees'...
    ,'Moment arm matrix'};
dlgname='Trial Information';
dlgnumlines=1;
cd('Readers')
load FFSReaderDLGDefault.mat
if isempty(dlganswer)
    for i=1:10
        dlganswer{i}='';
    end
end
dlganswer = inputdlg(dlgprompt,dlgname,dlgnumlines,dlganswer);
if ~isempty(dlganswer)
    save FFSReaderDLGDefault.mat dlganswer
end
cd ..
ReaderOutput.TrialDescription=dlganswer{1};
ReaderOutput.Data.RampUpTime=str2num(dlganswer{2});
ReaderOutput.Data.HoldTime=str2num(dlganswer{3});
ReaderOutput.Data.RampDownTime=str2num(dlganswer{4});
ReaderOutput.Data.NumTendons=str2num(dlganswer{5});
ReaderOutput.Data.SamplingRate=str2num(dlganswer{6});
ReaderOutput.Data.BaselineTension=str2num(dlganswer{7});
ReaderOutput.Data.TensionRange=str2num(dlganswer{8});
ReaderOutput.Data.JointAnglesInDegrees=str2num(dlganswer{9});
ReaderOutput.Data.Rmatrix=str2num(dlganswer{10});


ReaderOutput.Data.Time.Value = B(:,1);
ReaderOutput.Data.Time.Units = 'Seconds';

for i = 1:6
    ReaderOutput.Data.Motor(i).Force.Value = B(:,1+20+1+i);
    ReaderOutput.Data.Motor(i).Force.Units = 'Newtons';
end

ReaderOutput.Data.EndpointWrench(1).Name = 'Fx';
ReaderOutput.Data.EndpointWrench(1).Value = B(:,1+20+20+20+1);
ReaderOutput.Data.EndpointWrench(1).Units = 'Newtons';
    
ReaderOutput.Data.EndpointWrench(2).Name = 'Fy';
ReaderOutput.Data.EndpointWrench(2).Value = B(:,1+20+20+20+2);
ReaderOutput.Data.EndpointWrench(2).Units = 'Newtons';

ReaderOutput.Data.EndpointWrench(3).Name = 'Fz';
ReaderOutput.Data.EndpointWrench(3).Value = B(:,1+20+20+20+3);
ReaderOutput.Data.EndpointWrench(3).Units = 'Newtons';

ReaderOutput.Data.EndpointWrench(4).Name = 'Mx';
ReaderOutput.Data.EndpointWrench(4).Value = B(:,1+20+20+20+4);
ReaderOutput.Data.EndpointWrench(4).Units = 'Newton-Meters';

ReaderOutput.Data.EndpointWrench(5).Name = 'My';
ReaderOutput.Data.EndpointWrench(5).Value = B(:,1+20+20+20+5);
ReaderOutput.Data.EndpointWrench(5).Units = 'Newton-Meters';

ReaderOutput.Data.EndpointWrench(6).Name = 'Mz';
ReaderOutput.Data.EndpointWrench(6).Value = B(:,1+20+20+20+6);
ReaderOutput.Data.EndpointWrench(6).Units = 'Newton-Meters';















