function ReaderOutput = KamperReader(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription


strsep = EnableHelperFunction([],'strsep.m');

A = load(ReaderInput.Files{1});

tmp = strsep(ReaderInput.Files{1},'/');

ReaderOutput.TrialName = tmp{end}(1:end-4);
ReaderOutput.TrialDescription = 'series of EWA trials from a stroke subject'; % put in metadata
ReaderOutput.ReaderName = 'AllData';

ChannelName = {'VFx';'VFy';'VFz';'VMx';'VMy';'VMz';'FdiEmg'}; % put in metadata

NumTimePts = size(A,1);

ReaderOutput.Data.Time = [0:NumTimePts]/2000;
ReaderOutput.Data.TimeUnits = 'seconds';
ReaderOutput.Data.SampFreq = 2000;
ReaderOutput.Data.SampFreqUnits = 'Hz';

TrialCount = 1;

for i = 1:7
    ReaderOutput.Data.Channel(i).Name =  ChannelName{i};
    ReaderOutput.Data.Channel(i).Value = A(:,i);
end
