function ReaderOutput = ReadAllFiles_ViconOnly(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');
ProgramStatusIndicator = ReaderInput.ProgramStatusIndicator;

set(ProgramStatusIndicator,'string','Starting ''ReadAllFiles_ViconOnly'' reader...');
pause(0.1);

ReaderOutput.ReaderName = 'AllData';

%--------
%read vicon

ViconDataFile = ReaderInput.Files{1};

vFile = strsep(ViconDataFile,ReaderInput.PathSep);

fid = fopen(ViconDataFile);

Title = strsep(fgetl(fid),',');
Date = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.File = vFile{end};

ReaderOutput.TrialName = vFile{end}(1:end-10);

ReaderOutput.Data.Vicon.Date = Date{2};

Time = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.Time = Time{2};

Type = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.Type = Type{2};

Description = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.Description = Description{2};

ReaderOutput.TrialDescription = Description{2};  % added, HH

Notes = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.Notes = Notes{2};

fgetl(fid);   % skipped line
fgetl(fid);   % TRAJECTORIES

SampFreq = strsep(fgetl(fid),',');

ReaderOutput.Data.Vicon.Motion.SampFreq = str2num(SampFreq{1});
ReaderOutput.Data.Vicon.Motion.SampFreqUnits = SampFreq{2};

Objects = strsep(fgetl(fid),',');

c = 1;
for i = 1:length(Objects)
    if isempty(Objects{i}) == 0
        Markers{c} = Objects{i};
        c = c+1;
    end
end    
    
Labels = strsep(fgetl(fid),',');

fclose(fid);

fid = fopen(ViconDataFile);

% determine exact number of lines in vicon file
fseek(fid,-1000,'eof');
Line = fgetl(fid);
while Line ~= -1
    temp = strsep(Line,',');
    NumViconLines = str2num(temp{1});
    numcol = size(temp,2);
    Line = fgetl(fid);
end

fclose(fid);

set(ReaderInput.ProgramStatusIndicator,'string','Reading Vicon File ...');
pause(0.5)
Motion = csvread(ViconDataFile,11,0,[11 0 11+NumViconLines-1 length(Labels)-1]);
if numcol==2
    Analogue = csvread(ViconDataFile,16+NumViconLines,0,[16+NumViconLines 0 16+2*NumViconLines-1 1]);
else
    Analogue = zeros(NumViconLines,2);
    Analogue(:,1) = (1:1:NumViconLines)';
end
set(ReaderInput.ProgramStatusIndicator,'string','Reading Vicon File ... Finished');
pause(1);

ReaderOutput.Data.Vicon.Motion.Index = Motion(:,1);
ReaderOutput.Data.Vicon.Analogue = Analogue;
for i = 1:length(Markers)
   ReaderOutput.Data.Vicon.Motion.Marker(i,1).Name = Markers{i};
   Start = 2+3*(i-1);
   Finish = Start+2;
   ReaderOutput.Data.Vicon.Motion.Marker(i,1).Data = Motion(:,Start:Finish);
end

set(ProgramStatusIndicator,'string','''ReadAllFiles_ViconOnly'' reader finished');
pause(0.1);