function ReaderOutput = ReadEwaFiles(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction([],{'strsep.m'});

A = load(ReaderInput.Files{1});

temp = strsep(ReaderInput.Files{1},'/');

ReaderOutput.TrialName = temp{end};
ReaderOutput.TrialDescription = 'test';
ReaderOutput.ReaderName = 'AllData';

ChannelName = {'VFx';'VFy';'VFz';'VMx';'VMy';'VMz';'FdiEmg'}; % put in metadata

NumTimePts = size(A,1);

ReaderOutput.Data.Time = [0:NumTimePts]/2000;
ReaderOutput.Data.TimeUnits = 'seconds';
ReaderOutput.Data.SampFreq = 2000;
ReaderOutput.Data.SampFreqUnits = 'Hz';

j = 1;
for i = 3:9
    ReaderOutput.Data.Channel(j).Name =  ChannelName{j};
    ReaderOutput.Data.Channel(j).Value = A(:,i);
    j = j+1;
end
