function ReaderOutput = ReadForceMicroscope(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription



strsep = EnableHelperFunction([],'strsep.m');



fid = fopen(ReaderInput.Files{1});
ReaderOutput.TrialName = fgetl(fid);
ReaderOutput.TrialDescription = fgetl(fid);
ReaderOutput.Data.Labview.Date = fgetl(fid);
ReaderOutput.Data.Labview.Time = fgetl(fid);
Labels = fgetl(fid);
fclose(fid);

ChannelLabel = strsep(Labels,',');

M = dlmread(ReaderInput.Files{1},',',5,0);

for i = 1:length(ChannelLabel)
    ReaderOutput.Data.Labview.Channel(i).Name = ChannelLabel{i};
    ReaderOutput.Data.Labview.Channel(i).Data = M(:,i);
end

