function ReaderOutput = ReadSpike2DataFiles(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

RootDirectory = cd;

strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');

cd('HelperFunctions/son');

fid = fopen(ReaderInput.Files{1});
temp = strsep(ReaderInput.Files{1},'/');

Header = SONFileHeader(fid);

ReaderOutput.ReaderName = 'Spike2';
ReaderOutput.TrialName = temp{end}(1:end-4);
ReaderOutput.TrialDescription = Header.fileComment{4};

ReaderOutput.Data.SubjectName = Header.fileComment{1};
ReaderOutput.Data.Date = Header.fileComment{2};

ChanList = SONChanList(fid);
c = 1;
for i = 1:length(ChanList)
    if ChanList(i).kind == 1
        ReaderOutput.Data.Channel(c,1).Name = ChanList(i).title;
        ReaderOutput.Data.Channel(c,1).Comment = ChanList(i).comment;
        [p,header] = SONGetChannel(fid,i,'scale');
        ReaderOutput.Data.Channel(c,1).Time = [0:header.npoints-1]'*header.sampleinterval*10^-6;
        ReaderOutput.Data.Channel(c,1).Value = p;
        c = c+1;
    end
    if ChanList(i).kind == 2
        ReaderOutput.Data.Channel(c,1).Name = ChanList(i).title;
        ReaderOutput.Data.Channel(c,1).Comment = ChanList(i).comment; 
        ReaderOutput.Data.Channel(c,1).Value = SONGetEventChannel(fid,i);
    end
end

cd(RootDirectory);