function ReaderOutput = ReadLabviewDataFiles(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that
%     Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');

ViconDataFile = ReaderInput.Files{1};

fid = fopen(ViconDataFile);

Title = strsep(fgetl(fid),',');
Date = strsep(fgetl(fid),',');

fname = strsep(ViconDataFile,'.');

ReaderOutput.ReaderName = 'Vicon';
ReaderOutput.TrialName = [fname{1} '.mat'];    % a trial name is required (changed by H.H.)
ReaderOutput.TrialDescription = 'Vicon Data';

ReaderOutput.Data.Date = Date{2};

Time = strsep(fgetl(fid),',');

ReaderOutput.Data.Time = Time{2};

Type = strsep(fgetl(fid),',');

ReaderOutput.Data.Type = Type{2};

Description = strsep(fgetl(fid),',');

ReaderOutput.Data.Description = Description{2};

Notes = strsep(fgetl(fid),',');

ReaderOutput.Data.Notes = Notes{2};

fgetl(fid);   % skipped line
fgetl(fid);   % TRAJECTORIES

SampFreq = strsep(fgetl(fid),',');

ReaderOutput.Data.MotionSampFreq = str2num(SampFreq{1});
ReaderOutput.Data.MotionSampFreqUnits = SampFreq{2};

Objects = strsep(fgetl(fid),',');

c = 1;
for i = 1:length(Objects)
    if isempty(Objects{i}) == 0
        Markers{c} = Objects{i};
        c = c+1;
    end
end    
    
Labels = strsep(fgetl(fid),',');

[status,result] = system(['wc -l ' ViconDataFile]);
InitialReading = strsep(result,' ');
i = 1;
while isempty(InitialReading{i}) == 1
    i = i+1;
end
NumLines = round(str2num(InitialReading{i})/2);

Motion = zeros(NumLines,length(Labels));

Line = fgetl(fid);
i = 1;
wb = waitbar(0,'Reading Vicon Data File...');
while isempty(Line) == 0
    waitbar(i/NumLines,wb)
    vec = strsep(Line,',');
    for j = 1:length(vec)
        temp = str2num(vec{j});
        if isempty(temp) == 0
            Motion(i,j) = temp;
        else
            Motion(i,j) = NaN;
        end
    end
    i = i+1;
    Line = fgetl(fid);
end
close(wb)

Motion = Motion(1:i-1,:);

ReaderOutput.Data.Motion.Index = Motion(:,1);
for i = 1:length(Markers)
   ReaderOutput.Data.Motion.Marker(i,1).Name = Markers{i};
   Start = 2+3*(i-1);
   Finish = Start+2;
   ReaderOutput.Data.Motion.Marker(i,1).Data = Motion(:,Start:Finish);
end
    

fgetl(fid);     %ANALOG
AnalogFreq = strsep(fgetl(fid),',');
ReaderOutput.Data.AnalogSampFreq = str2num(AnalogFreq{1});
ReaderOutput.Data.AnalogSampFreqUnits = AnalogFreq{2};

Labels = strsep(fgetl(fid),',');
Units = strsep(fgetl(fid),',');

Line = fgetl(fid);
i = 1;
while isempty(Line) == 0
    vec = strsep(Line,',');
    for j = 1:length(vec)
       Analog(i,j) = str2num(vec{j}); 
    end
    i = i+1;
    Line = fgetl(fid);
end

ReaderOutput.Data.Sync.Index = Analog(:,1);
ReaderOutput.Data.Sync.Signal = Analog(:,2);

fclose(fid);

%cd /Volumes/bbdlMember/Documents/DatabaserProject
