function ReaderOutput = ReadVideoFileManually(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction(ReaderInput.HelperFunctions,'strsep.m');

ReaderOutput.ReaderName = 'Kinematics';
ReaderOutput.TrialName = '';
ReaderOutput.TrialDescription = '';

vidObj = mmreader(ReaderInput.Files{1});
figure(1)
set(1,'doublebuffer','on')

load(ReaderInput.TrialFile);
if isfield(Trial,(ReaderOutput.ReaderName)) == 1  %events have been added before
    ReaderOutput.Data = Trial.(ReaderOutput.ReaderName);
    EventCount = length(Trial.Kinematics.VideoEvent)+1;
else % events have not been added before
    ReaderOutput.Data.VideoFile = vidObj.Name;
    Trial.(ReaderOutput.ReaderName).VideoFile = vidObj.Name;
    ReaderOutput.Data.FrameRate = vidObj.FrameRate;
    Trial.(ReaderOutput.ReaderName).FrameRate = vidObj.FrameRate;
    ApproxStart = inputdlg({'Approximate frame number at labview start:'});
    ReaderOutput.Data.ApproxFrameNumAtLabviewStart = str2num(ApproxStart{1});
    Trial.(ReaderOutput.ReaderName).ApproxFrameNumAtLabviewStart = str2num(ApproxStart{1});
    EventCount = 1;
end
    
EventParams = inputdlg({'Event name';'Start frame';'End frame';'Frame step'},'Cancel to finish');

while isempty(EventParams) == 0
    EventName = EventParams{1};
    StartFrame = str2num(EventParams{2});
    EndFrame = str2num(EventParams{3});
    FrameStep = str2num(EventParams{4});
    ReaderOutput.Data.VideoEvent(EventCount).Name = EventName;
    Trial.(ReaderOutput.ReaderName).VideoEvent(EventCount).Name = EventName;
    FramesToLookAt = StartFrame:FrameStep:EndFrame;
    FrameCount = 1;
    for FrameNum = FramesToLookAt
       vidFrame = read(vidObj,FrameNum);
       imagesc(vidFrame)
       B = ginput(8);
       ReaderOutput.Data.VideoEvent(EventCount).FrameNum(FrameCount,1) = FrameNum;
       Trial.(ReaderOutput.ReaderName).VideoEvent(EventCount).FrameNum(FrameCount,1) = FrameNum;
       ReaderOutput.Data.VideoEvent(EventCount).MarkerLocations(:,:,FrameCount) = B';
       Trial.(ReaderOutput.ReaderName).VideoEvent(EventCount).MarkerLocations(:,:,FrameCount) = B';
       FrameCount = FrameCount+1;
    end
    save(ReaderInput.TrialFile,'Trial');
    EventCount = EventCount+1;
    EventParams = inputdlg({'Event name';'Start frame';'End frame';'Frame step'},'Cancel to finish');
end