function ReaderOutput = CppsFmriP002S002(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

CppsEvReader = EnableHelperFunction([],{'fMRI','CppsEvReader.m'});
strsep = EnableHelperFunction([],'strsep.m');

% will be reading nii files, so change directory to NifTi helpers  
BaseDirectory = cd;
cd('HelperFunctions/nifti');

% load raw nii file
try 
    set(ReaderInput.ProgramStatusIndicator,'string','Loading filtered nii...');pause(0.5);
    system(['gunzip ' ReaderInput.Files{1}]);
    tempfile = ReaderInput.Files{1}(1:end-3);
    reslice_nii(tempfile,tempfile);
    nii = load_nii(tempfile);
    system(['gzip ' tempfile]);
    set(ReaderInput.ProgramStatusIndicator,'string','Preprocessed filtered (native coord.) loaded.');pause(0.5);
catch err
    set(ReaderInput.ProgramStatusIndicator,'string','ERROR: There was an error reading the raw nii file. See matlab command window for details.');
    cd(BaseDirectory);
    error(['Databaser had an error: ' err.message]);
end

EV = CppsEvReader(fopen(ReaderInput.Files{2}));

temp1 = strsep(ReaderInput.Files{1},'/');
temp2 = strsep(temp1{end},'_');
ReaderOutput.TrialName = temp2{1};
ReaderOutput.TrialDescription = EV.Description;
ReaderOutput.ReaderName = 'AllData';
ReaderOutput.Data.EV = EV;
ReaderOutput.Data.Imaging = nii;