function ReaderOutput = Cpps_EV(ReaderInput)

% Readers are .m functions that look at data files and produce standard matlab data

% ReaderInput
%     .Files - cell array of file names passed to the reader
%     .HelperFunctions - cell array of helper function names to be used with EnableHelperFunction
%     .ProgramStatusIndicator - a handle to the Program Status Indicator on the front panel so that status can be updated from within the reader

% ReaderOutput
%     .Data - a struct (of arbitrary structure) that you want written to the trial file
%     .ReaderName - a string naming the data so that the trial file will have Trial.ReaderName = Data
%     .TrialName - a string that either names the trial or is empty.  The reader producing a trial name must be run first
%     .TrialDescription - a string describing the trial so that Trial.TrialDescription = TrialDescription

strsep = EnableHelperFunction([],{'strsep.m'});

temp1 = strsep(ReaderInput.Files{1},'/');
temp2 = strsep(temp1{end},'_');

ReaderOutput.ReaderName = 'EV';
ReaderOutput.TrialName = temp2{1};

fid = fopen(ReaderInput.Files{1});

% extract lines from file into a cell array
Line{1} = fgetl(fid);
i = 2;
while strcmp(Line{i-1}(1),'E') == 0
   Line{i} = fgetl(fid); 
   i = i+1;
end

trcount = 0;

% categorize lines and extract data
for i = 1:length(Line)
    switch Line{i}(1)
        case 'S' % start of trial
            K1 = strfind(Line{i},':');
            K2 = strfind(Line{1},'.');
            EV.Description = Line{i}(K2+2:K1(1)-1);
            str2 = Line{i}(K1+1:end);
            K2 = strfind(str2,'at');
            time{i} = str2(K2+3:end);
            event{i} = 'Start';
        case 'f' % scanner TR
            K = strfind(Line{i},'at');
            time{i} = Line{i}(K+3:end);
            event{i} = 'TR';
        case 'V' % change in pain rating
            K = strfind(Line{i},'at');
            time{i} = Line{i}(K+3:end);
            event{i} = 'PainChange';
            K2 = strfind(Line{i},'to');
            pain{i} = Line{i}(K2+3:K-2);
        case 'E' % Trial end
            K = strfind(Line{i},'at');
            time{i} = Line{i}(K+3:end);
            event{i} = 'End';
    end
    
    K = strfind(Line{i},'finished');
    if isempty(K) == 0
        str2 = Line{i}(K:end);
        K2 = strfind(str2,'at');
        time{i} = str2(K2+3:end);
        event{i} = str2(1:K2-2);
    end
    
    K = strfind(Line{i},'started');
    if isempty(K) == 0
        str2 = Line{i}(K:end);
        K2 = strfind(str2,'at');
        time{i} = str2(K2+3:end);
        event{i} = str2(1:K2-2);
    end
    
end

PainTemp = 0;

k = 0;

for i = 1:length(time)
   EV.Time(i) = TimeDifference(time{1},time{i});
   if strcmp(event{i},'TR') == 1
       if trcount > 0
        EV.TR(i) = 1;
       else
           trcount = 1;
       end
   else 
       EV.TR(i) = 0;
   end
   if strcmp(event{i},'PainChange') == 1
       PainTemp = str2num(pain{i});
       EV.Pain(i) = PainTemp;
   else
       EV.Pain(i) = PainTemp;
   end
   
   EV.TherapistLocation(i) = k;
   
   if strcmp(event{i},['started ' num2str(k+1)]) == 1
       k = k+1;
   end
   
end

fclose(fid);

ReaderOutput.TrialDescription = EV.Description;
ReaderOutput.Data.Time = EV.Time;
ReaderOutput.Data.Pain = EV.Pain;
ReaderOutput.Data.TR = EV.TR;
ReaderOutput.Data.TherapistLocation = EV.TherapistLocation;





function deltaT = TimeDifference(str1,str2)


K = strfind(str1,':');
H1 = str2num(str1(1:K(1)-1));
M1 = str2num(str1(K(1)+1:K(2)-1));
S1 = str2num(str1(K(2)+1:end));

K = strfind(str2,':');
H2 = str2num(str2(1:K(1)-1));
M2 = str2num(str2(K(1)+1:K(2)-1));
S2 = str2num(str2(K(2)+1:end));

deltaH = H2-H1;
deltaM = M2-M1;
deltaS = S2-S1;

deltaT = 60^2*deltaH + 60*deltaM + deltaS;





